/*
 * Copyright (C) 2005-2007 Opened Hand Ltd.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Author: Ross Burton <ross@openedhand.com>
 *
 */

/*
 * TODO: if gtk+ 2.10, handle symbolic colours
 */

#include <string.h>
#include <glib/gi18n.h>
#include <gconf/gconf-client.h>
#include <gtk/gtk.h>

static GConfClient *gconf;
static GtkWidget *theme_combo, *font_button, *handed_check;
static GtkListStore *theme_store;

enum {
  COL_NAME, /* Human readable name */
  COL_GTK, /* GTK+ theme */
